#
# spec file for package libgnomeprint
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           libgnomeprint
#
Version:        2.18.8
Release:        bp153.1.17
Summary:        The GNOME 2.x Printing Library
License:        GPL-2.0-or-later AND LGPL-2.1-or-later
Group:          Development/Libraries/GNOME
Source:         %{name}-%{version}.tar.bz2
Source1:        libgnomeprint-icons.tar.gz
Source99:       baselibs.conf
Patch0:         libgnomeprint-suseconfig.dif
Patch1:         libgnomeprint.patch
Patch3:         libgnomeprint-pdf-invalid-path-176712.patch
# PATCH-FIX-UPSTREAM libgnomeprint-missing-include.patch bgo#653388 vuntz@opensuse.org -- Add missing include to fix build
Patch4:         libgnomeprint-missing-include.patch
# PATCH-FIX-UPSTREAM libgnomeprint-use-recommended-freetype-include.patch hrvoje.senjan@gmail.com -- Use freetype upstream recommended #include style
Patch5:         libgnomeprint-use-recommended-freetype-include.patch
# PATCH-FIX-UPSTREAM libgnomeprint-bison-3.0.patch dimstar@opensuse.org -- Fix build with bison 3.0 (upstream no longer maintained)
Patch6:         libgnomeprint-bison-3.0.patch
BuildRequires:  bison
BuildRequires:  cups-devel
BuildRequires:  flex
BuildRequires:  gtk-doc
BuildRequires:  intltool
BuildRequires:  libart_lgpl-devel
BuildRequires:  libgnomecups-devel
BuildRequires:  libtool
BuildRequires:  libxml2-devel
BuildRequires:  pango-devel
BuildRequires:  popt-devel
BuildRequires:  translation-update-upstream
BuildRequires:  zlib-devel
Recommends:     %{name}-lang

%description
This package contains the GNOME 2.x printing library, which provides a
simple and clean API for GNOME programs that have to print documents.

%package devel
Summary:        Include files and libraries mandatory for development with libgnomeprint
Group:          Development/Libraries/GNOME
Requires:       %{name} = %{version}
Requires:       glib2-devel
Requires:       libart_lgpl-devel
Requires:       libxml2-devel
Requires:       pango-devel
#

%description devel
This package contains all necessary include files and libraries needed
to compile and link applications that use libgnomeprint.

%package doc
Summary:        Documentation for libgnomeprint
Group:          Development/Libraries/GNOME
%if 0%{?suse_version} >= 1120
BuildArch:      noarch
%endif

%description doc
This package contains documentation for the GNOME 2.x printing library,
which provide a simple and clean API for GNOME programs that have to
print documents.

%lang_package

%prep
%setup -q
translation-update-upstream
tar xvfz %{SOURCE1}
%patch0 -p1
%patch1
%patch3
%patch4 -p1
%patch5
%patch6

%build
autoreconf -f -i
# can use openprinting/papi
# FIXME: Which packages are required for rebuild of gtk-doc stuff?
%configure\
	--disable-static\
	--disable-gtk-doc
make %{?_smp_mflags}

%install
%make_install
find %{buildroot} -type f -name "*.la" -delete -print
%find_lang libgnomeprint-2.2

%post -p /sbin/ldconfig
%postun -p /sbin/ldconfig

%files
%license COPYING
%doc AUTHORS README NEWS ChangeLog
%{_datadir}/gnome-print-2.0
%{_datadir}/libgnomeprint
%{_libdir}/*.so.*
%{_libdir}/libgnomeprint

%files lang -f libgnomeprint-2.2.lang

%files devel
%{_includedir}/libgnomeprint-2.2
%{_libdir}/*.so
%{_libdir}/pkgconfig/libgnomeprint-2.2.pc

%files doc
%doc %{_datadir}/gtk-doc/html/*

%changelog
* Wed Feb 28 2018 dimstar@opensuse.org
- Modernize spec-file by calling spec-cleaner
* Tue Jan 13 2015 dimstar@opensuse.org
- Add libgnomeprint-bison-3.0.patch: Fix build with Bison 3.0.
* Sat Dec 14 2013 hrvoje.senjan@gmail.com
- Add libgnomeprint-use-recommended-freetype-include.patch:
  Freetype upstream recommends using their macros together with
  ft2build include. Positive sideeffect is that this patch makes it
  build with both freetype2 2.5.1, and older versions.
* Fri Mar  1 2013 dimstar@opensuse.org
- Spec-cleanup using format_spec_file service.
* Mon Feb 13 2012 coolo@suse.com
- patch license to follow spdx.org standard
* Sun Nov 13 2011 coolo@suse.com
- Add libtool as explicit BuildRequires to avoid implicit
  dependency from prjconf.
* Wed Oct 12 2011 vuntz@opensuse.org
- Add libgnomeprint-missing-include.patch: add missing include to
  fix build.
* Sun Feb 27 2011 aj@suse.de
- Change lang package Requires to Recommends since it is not
  mandatory at runtime.
* Tue Sep 28 2010 vuntz@opensuse.org
- Update to version 2.18.8:
  + Updated translations.
* Tue Mar 30 2010 vuntz@opensuse.org
- Update to version 2.18.7:
  + Cygwin fixes
  + Updated translations
- Remove en@shaw translations on 11.2 and earlier.
* Fri Dec 18 2009 jengelh@medozas.de
- Add baselibs.conf as a source
- Package documentation as noarch
* Wed Nov 25 2009 dimstar@opensuse.org
- Update patches to apply with fuzz=0.
* Fri Mar  6 2009 vuntz@novell.com
- Update to version 2.18.6:
  + Fix warnings about missing format specifiers
  + Updated translations
- Remove -fno-strict-aliasing from CFLAGS.
- Use makeinstall.
- Drop autobuild-warnings.patch: fixed upstream another way.
- Remove check for old version of openSUSE.
* Mon Feb 16 2009 sbrabec@suse.cz
- Added support for translation-update-upstream (FATE#301344).
* Wed Jan  7 2009 olh@suse.de
- obsolete old -XXbit packages (bnc#437293)
* Tue Sep 23 2008 maw@suse.de
- Update to version 2.18.5:
  + Updated translations.
* Thu Apr 10 2008 ro@suse.de
- added baselibs.conf file to build xxbit packages
  for multilib support
* Mon Feb 18 2008 maw@suse.de
- Update to version 2.18.4:
  + Support searching and cut'n'paste of text in PDF files
    output by libgnomeprint
  + Fix problem in the postcript backend that caused images
    to be printed as black squares.
* Wed Jan 30 2008 rodrigo@suse.de
- Update to version 2.18.3:
  * Fix use of uninitialized variable
  * Fix some dead code
  * Remove more popt usage
  * Cleanups
* Tue Sep 18 2007 sbrabec@suse.cz
- Updated to version 2.18.2:
  * updated Arabic translation
* Thu Aug 30 2007 maw@suse.de
- Update to version 2.18.1:
  + Fix a crash in Gedit caused by a typo
  + Fixed some compiler warnings
  + Updated translations
- Refresh autobuild-warnings.patch, as some of it has made it
  upstream.
* Wed Aug  8 2007 maw@suse.de
- Use %%fdupes
- Split off a -lang subpackage
- s#%%run_ldconfig#/sbin/ldconfig/ in %%post and %%postun.
* Wed Apr 11 2007 maw@suse.de
- Update to version 2.18.0
- Minor code cleanups
- Fix for a possible crash
- Updated translations.
* Thu Mar 29 2007 maw@suse.de
- Add flex to buildrequires.
* Thu Mar 29 2007 maw@suse.de
- Add bison to buildrequires.
* Fri Mar 23 2007 maw@suse.de
- Update to version 2.17.92
- Only minor changes since 2.17.91.
* Mon Feb 19 2007 maw@suse.de
- Update to version 2.17.91
- Remove bnc-8691.patch which is now upstream
- Add autobuild-warnings.patch; the contents of patch have been
  filed on bugzilla.gnome.org and should show up in a subsequent
  release.
* Tue Feb 13 2007 sbrabec@suse.cz
- Do not build unusable static libraries (#238552#c17).
* Sat Jan 20 2007 sbrabec@suse.cz
- Build correctly in older products.
* Mon Jan  8 2007 sbrabec@suse.cz
- More spec file cleanups.
* Mon Jan  8 2007 maw@suse.de
- Move to /usr
- Some specfile cleanup.
* Thu Dec 28 2006 jhargadon@suse.de
- removed unused libtool files (#223656)
* Thu May 18 2006 joeshaw@suse.de
- Add a patch to fix a crash when trying to save to a PDF file
  that you can't write to.  (bnc #176712)
* Tue May  9 2006 fejj@suse.de
- fix unlocalised text on two tabs of print dialog (bnc#8691)
* Sun Feb  5 2006 aj@suse.de
- Cleanup BuildRequires.
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Wed Oct 12 2005 ro@suse.de
- remove upstreamed patch
* Thu Oct  6 2005 gekker@suse.de
- Update to version 2.12.1
- Fix crashes in print dialogs (#118797)
* Thu Sep  8 2005 sbrabec@suse.cz
- Fixed directory ownership.
* Tue Sep  6 2005 gekker@suse.de
- Update to version 2.12.0 (GNOME 2.12)
- Fix return of random data
* Tue Jun 21 2005 gekker@suse.de
- Update to version 2.11.0
* Wed Jun  1 2005 sbrabec@suse.cz
- Fixed devel requirements.
* Wed Mar 23 2005 jody@suse.de
- upstream 2.10.2 bug fix release
- https://bugzilla.innerweb.novell.com/show_bug.cgi?id=73854
  kerning support in ps2/pdf
- https://bugzilla.innerweb.novell.com/show_bug.cgi?id=73773
  more than one lpr printer
- https://bugzilla.innerweb.novell.com/show_bug.cgi?id=73774
  only display duplex when it is available.
* Sat Mar 19 2005 jody@suse.de
- fix pdf generation
* Wed Mar 16 2005 jody@suse.de
- upstream 2.10.1 bug fix release
- https://bugzilla.innerweb.novell.com/show_bug.cgi?id=72837
- various leaks
- problems in pdf with some ttf fonts.
* Tue Mar  8 2005 jody@suse.de
- upstream 2.10.0
- improved pango integration
- faster status from cups
* Tue Jan 18 2005 clahey@suse.de
- Updated to 2.8.2.
* Fri Nov 19 2004 ro@suse.de
- removed extra aclocal include directive
* Mon Oct 25 2004 ro@suse.de
- locale rename: no -> nb
* Mon Oct  4 2004 jody@suse.de
- update to 2.8.0.1
- updated translations
- Fix the display of printer state in the job count column
* Mon Sep 13 2004 jody@suse.de
- update to 2.8.0
- Fix rotated text export to pdf
- Fix font subsetting for non-ascii text in ps and pdf
- Use libgnomecups as cups backend
* Sat Jul 31 2004 jody@suse.de
- updated to 2.7.1
- dropped the icon patch
- downgraded the pango req
* Tue Jun 22 2004 jody@suse.de
- Updated to version 2.6.2 and added an icon patch
* Fri Apr 23 2004 sbrabec@suse.cz
- Updated to version 2.6.1 (GNOME 2.6).
* Mon Mar 15 2004 sbrabec@suse.cz
- Include %%{prefix}/share/gnome-print-2.0 to %%files.
* Wed Mar 10 2004 hhetter@suse.de
- fix icon installation path for the print dialog
* Fri Feb 27 2004 hhetter@suse.de
- updated to version 2.5.3: better cups interaction
- added ximian icon set for print dialog
* Tue Jan 20 2004 hhetter@suse.de
- updated to version 2.4.2, freetype fixes included
* Sat Jan 10 2004 adrian@suse.de
- add %%defattr
* Thu Jan  8 2004 ro@suse.de
- fix build with current freetype
* Wed Oct  8 2003 sbrabec@suse.cz
- Updated to version 2.4.0 (GNOME 2.4).
* Mon Jul 14 2003 sbrabec@suse.cz
- GNOME prefix change to /opt/gnome.
* Thu Jun 26 2003 sbrabec@suse.cz
- Updated to version 2.2.1.3.
* Mon Jun 23 2003 sbrabec@suse.cz
- Updated to version 2.2.1.2.
- Use %%find_lang.
- Fixed directory packaging.
- Branched libgnomeprint-doc.
- Prefix clash fix - gtk-doc files.
* Sun Jun  1 2003 ro@suse.de
- include devel-docs to devel subpackage
- add rest of static libs to devel subpackage
* Fri Mar  7 2003 hhetter@suse.de
- include the libgnomeprint-file and libgnomeprint-lpr
  modules (Bug Id#24817)
* Thu Feb  6 2003 hhetter@suse.de
- updated to version 2.2.1.1 [GNOME 2.2.0]
* Tue Jan 28 2003 hhetter@suse.de
- updated to version 2.2.1
* Wed Jan 15 2003 hhetter@suse.de
- updated to version 2.1.8
- added expat to needeforbuild
- recheck filelist
- remove the installer for now, as gnome-font-install is
  no longer included
* Thu Oct 31 2002 hhetter@suse.de
- updated to version 1.116.0
* Tue Oct 22 2002 sbrabec@suse.cz
- Remove /var/adm/SuSEconfig/run-libgnomeprint from %%files and keep it
  only in %%post (fixes #20031).
* Mon Sep  9 2002 ro@suse.de
- removed libgnomeui/libgnomeui-devel from neededforbuild (unused)
* Fri Aug  9 2002 hhetter@suse.de
- added openssl to neededforbuild
* Sat Jul 27 2002 adrian@suse.de
- add %%run_ldconfig
* Tue Jun 25 2002 hhetter@suse.de
- fix typo in SuSEconfig.libgnomeprint
* Tue Jun 11 2002 hhetter@suse.de
- fix filelist
* Fri Jun  7 2002 hhetter@suse.de
- updated to version 1.115.0
* Wed Jun  5 2002 hhetter@suse.de
- updated to version 1.114.0 source frozen
* Wed May 15 2002 ro@suse.de
- use libdir
* Wed Apr 10 2002 hhetter@suse.de
- updated to version 1.112.0 [gnome desktop beta3]
* Mon Apr  8 2002 coolo@suse.de
- fixed automake usage
* Fri Feb  1 2002 hhetter@suse.de
- updated to version 1.110.0 [gnome desktop alpha2]
* Thu Jan 31 2002 ro@suse.de
- changed neededforbuild <libpng> to <libpng-devel-packages>
* Thu Jan 17 2002 hhetter@suse.de
- prefixed to /opt/gnome2
- adapted SuSEconfig-script
* Thu Jan 10 2002 hhetter@suse.de
- initial SuSE package for GNOME 2.0 platform
- created SuSEconfig-script
